summaryrefslogtreecommitdiffstats
path: root/net/socket/ssl_socket.h
diff options
context:
space:
mode:
authorwtc@chromium.org <wtc@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-15 00:20:58 +0000
committerwtc@chromium.org <wtc@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-15 00:20:58 +0000
commit1bc6f5e2827bbf1fe571d2b6f085ceff23644e1a (patch)
treed804ca496db0952db185663f12193c7108854573 /net/socket/ssl_socket.h
parentb518852c1a1ccf23fd3ee12d49895009cb8a5aa0 (diff)
downloadchromium_src-1bc6f5e2827bbf1fe571d2b6f085ceff23644e1a.zip
chromium_src-1bc6f5e2827bbf1fe571d2b6f085ceff23644e1a.tar.gz
chromium_src-1bc6f5e2827bbf1fe571d2b6f085ceff23644e1a.tar.bz2
Add a boolean |has_context| argument to the TLS ExportKeyingMaterial
method to support both nonexistent context and zero-length context. R=agl@chromium.org,rsleevi@chromium.org BUG=none TEST=existing unit tests Review URL: http://codereview.chromium.org/9663043 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@126799 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/socket/ssl_socket.h')
-rw-r--r--net/socket/ssl_socket.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/net/socket/ssl_socket.h b/net/socket/ssl_socket.h
index 1291b46..bd063a4 100644
--- a/net/socket/ssl_socket.h
+++ b/net/socket/ssl_socket.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -18,11 +18,14 @@ public:
virtual ~SSLSocket() {}
// Exports data derived from the SSL master-secret (see RFC 5705).
// The call will fail with an error if the socket is not connected, or the
// SSL implementation does not support the operation.
virtual int ExportKeyingMaterial(const base::StringPiece& label,
+ bool has_context,
const base::StringPiece& context,
- unsigned char *out,
+ unsigned char* out,
unsigned int outlen) = 0;
};
@@ -18,11 +18,14 @@ public:
virtual ~SSLSocket() {}
// Exports data derived from the SSL master-secret (see RFC 5705).
- // The call will fail with an error if the socket is not connected, or the
- // SSL implementation does not support the operation.
+ // If |has_context| is false, uses the no-context construction from the
+ // RFC and |context| is ignored. The call will fail with an error if
+ // the socket is not connected or the SSL implementation does not
+ // support the operation.
virtual int ExportKeyingMaterial(const base::StringPiece& label,